@@ -157,7 +157,8 @@ def modelar_clasificacion_binaria(strategy="", X_train=None,y_train=None,X_test=
             print ("SE NECESITA UNA URL PARA PROCESAR CROSS VALIDATION")
             
         else:
-        
+            print("INICIO CROSS VALIDATION: ")
+            print(params)
             args_cv = { 'X_train':X_train, 'y_train': y_train, 'X_test': X_test, 'y_test': y_test, 'params':params,
                         "metric":metric,"num_rounds":num_rounds_cv,"random_state":random_state,
                         "api":api , "url":url , "cv_n_split" :cv_n_split, "shuffle_cv" :shuffle_cv,
@@ -187,7 +188,8 @@ def modelar_clasificacion_binaria(strategy="", X_train=None,y_train=None,X_test=
 
 
 def generate_cv_result(X_train=None,y_train=None,X_test=None,y_test=None,api=None, num_rounds = None , metric=None, 
-                       params =None ,  url=None, shuffle_cv = False ,shuffle_cv_test_size=None, cv_n_split=None, random_state=42):
+                       params =None ,  url=None, shuffle_cv = False ,shuffle_cv_test_size=None, cv_n_split=None,
+                       random_state=42):
     
    print(X_train.shape)
    X_t_ = X_train.append(X_test)
@@ -244,6 +246,10 @@ def generate_cv_result(X_train=None,y_train=None,X_test=None,y_test=None,api=Non
              
 
 def kpis_cross_validation(list_path=[], n_splits=5,url_out=None,postfix=""):
+  
+    
+    list_train_sensitivity = []
+    list_train_specificity = []
     
     list_train_precision = []
     list_train_recall = []
@@ -258,6 +264,8 @@ def kpis_cross_validation(list_path=[], n_splits=5,url_out=None,postfix=""):
     list_valid_average_precision = []
     list_valid_roc_auc = []
     
+    
+    
 
     
     for i in range(n_splits):
@@ -275,6 +283,15 @@ def kpis_cross_validation(list_path=[], n_splits=5,url_out=None,postfix=""):
        precision_train, recall_train, f1_train, support_train = precision_recall_fscore_support(y_train_cv, y_pred_train_cv ,average="binary",pos_label=1)
        train_average_precision = average_precision_score(y_train_cv, y_prob_uno_train_cv)      
        roc_auc_train = roc_auc_score(y_train_cv, y_prob_uno_train_cv) 
+       
+       cm1 = confusion_matrix(y_train_cv,y_pred_train_cv)
+       #total1=sum(sum(cm1))
+       specificity_train = cm1[0,0]/(cm1[0,0]+cm1[0,1])
+       sensitivity_train = cm1[1,1]/(cm1[1,0]+cm1[1,1])
+       
+       
+       list_train_sensitivity.append(sensitivity_train)
+       list_train_specificity.append(specificity_train)
         
        list_train_precision.append(precision_train)
        list_train_recall.append(recall_train)
@@ -304,6 +321,9 @@ def kpis_cross_validation(list_path=[], n_splits=5,url_out=None,postfix=""):
        list_valid_roc_auc.append(roc_auc_valid)
        
    
+    mean_train_sensitivity = statistics.mean(list_train_sensitivity) 
+    mean_train_specificity = statistics.mean(list_train_specificity) 
+    
 
     mean_valid_precision = statistics.mean(list_valid_precision)           
     std_valid_precision = statistics.pstdev(list_valid_precision)
@@ -370,7 +390,11 @@ def kpis_cross_validation(list_path=[], n_splits=5,url_out=None,postfix=""):
     
                    {"Metric":"ROC AUC","Splits":n_splits,"Data":"Test","Mean":mean_valid_roc_auc,"SD":std_valid_roc_auc,"Min":min_valid_roc_auc,"Max":max_valid_roc_auc},
                    {"Metric":"ROC AUC","Splits":n_splits,"Data":"Train","Mean":mean_train_roc_auc,"SD":std_train_roc_auc,"Min":min_train_roc_auc,"Max":max_train_roc_auc},               
-                   ]
+                  
+                   {"Metric":"sensitivity","Splits":n_splits,"Data":"Train","Mean":mean_train_sensitivity,"SD":0,"Min":0,"Max":0},               
+                   {"Metric":"specificity","Splits":n_splits,"Data":"Train","Mean":mean_train_specificity,"SD":0,"Min":0,"Max":0},               
+                   
+                  ]
     
     df = pd.DataFrame(result_kpis)
     
